@@ -13,7 +13,7 @@
 #include <gst/gst.h>
 #include <gtk/gtk.h>
 #include "gingerblue.h"
-#include "file.h"
+#include "gingerblue-file.h"
 
 gint
 gb_exit (void) {
